@@ -65,9 +65,9 @@ def py2ri_pandasseries(obj):
         res = numpy2ri.numpy2ri(obj.values)
     # "index" is equivalent to "names" in R
     if obj.ndim == 1:
-        res.do_slot_assign('names', ListVector({'x': conversion.py2ri(obj.index)}))
+        res.do_slot_assign('names', StrVector(tuple(str(x) for x in obj.index)))
     else:
-        res.do_slot_assign('dimnames', ListVector(conversion.py2ri(obj.index)))
+        res.do_slot_assign('dimnames', SexpVector(conversion.py2ri(obj.index)))
     return res
 
 @ri2py.register(SexpVector)
